stations = {
    "Abisko": {
        "acronym": "ANS",
        "name": "Abisko Scientific Research Station",
        "is_active": True,
        "locations":
           {
               0:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "ANS",
                   "description": "",
                   "ecosystems":[],
                   "is_active": True,                   
               },    
                       
               1:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "OPH-1",
                   "description": "Phenocam Area 1, P01-ROI1-LG",
                   "ecosystems":[],
                   "is_active": True,
                   
               },
               2:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "OPH-2",
                   "description": "Phenocam Area 2, P01-ROI2-R",
                   "ecosystems":[],
                   "is_active": True,
               },
               3:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "OPH-3",
                   "description": "Phenocam Area 3, P01-ROI3-B",
                   "ecosystems":[],
                   "is_active": True,
               },
               4:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "OPH-4",
                   "description": "Phenocam Area 4, P01-ROI4-LB",
                   "ecosystems":[],
                   "is_active": True,
               5:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "OPH-5",
                   "description": "Phenocam Area 5, P01-ROI5-P",
                   "ecosystems":[],
                   "is_active": True,
               },               
               6:{
                   "name": "Abisko Scientific Research Station",
                   "acronym": "M45P01",
                   "description": "mast 4.5m Phenocam 01, P01 center",
                   "ecosystems":[],
                   "is_active": True,
               },
               7:{
                   "name": "Stordalen Mire Spectral West",
                   "acronym": "SSW",
                   "description": "",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               8:{
                   "name": "Stordalen Mire Spectral East",
                   "acronym": "SSE",
                   "description": "",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               9:{
                   "name": "Stordalen Mire Spectral",
                   "acronym": "SMS",
                   "description": "",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               10:{
                   "name": "Stordalen Mire Spectral West_Sky-01",
                   "acronym": "SWS01",
                   "description": "Sky_SWE-ANS-SSW-MIR-F01-01",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               11:{
                   "name": "Stordalen Mire Spectral West_Sky-02",
                   "acronym": "SWS02",
                   "description": "Sky_SWE-ANS-SSW-MIR-F01-02_2020",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               12:{
                   "name": "Stordalen Mire Spectral East_Decagon_01",
                   "acronym": "SED01",
                   "description": "Decagon_SWE-ANS-SSE-MIR-F02-01",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
               13:{
                   "name": "Stordalen Mire Spectral East_Decagon_02",
                   "acronym": "SED02",
                   "description": "Decagon_SWE-ANS-SSE-MIR-F02-02_2020",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
              14:{
                   "name": "Stordalen Mire Spectral East_Sky_01",
                   "acronym": "SES01",
                   "description": "Sky_SWE-ANS-SSE-MIR-F02-01",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
              15:{
                   "name": "Stordalen Mire Spectral East_Sky_02",
                   "acronym": "SES02",
                   "description": "Sky_SWE-ANS-SSE-MIR-F02-02_2020",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
              
              16:{
                   "name": "Miellejohka",
                   "acronym": "MKA",
                   "description": "UAV Miellejohka2020",
                   "ecosystems":["HEA"],
                   "is_active": True,
               },
                                
              17:{
                   "name": "Stordalen Forest",
                   "acronym": "SUF",
                   "description": "UAV Stordalen_Forest2020",
                   "ecosystems":["FOR"],
                   "is_active": True,
               },
                                
              18:{
                   "name": "Stordalen UAV Mire ",
                   "acronym": "SUM",
                   "description": "UAV abiskoMire2020",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },
              
              19:{
                   "name": "Stordalen Mire North",
                   "acronym": "STO-MIR-North-UAV",
                   "description": "UAV 2024",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },    

              20:{
                   "name": "Stordalen Mire Center",
                   "acronym": "STO-MIR-Center-UAV",
                   "description": "UAV 2024",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },    
    
              21:{
                   "name": "Stordalen Mire South",
                   "acronym": "STO-MIR-South-UAV",
                   "description": "UAV 2024",
                   "ecosystems":["MIR"],
                   "is_active": True,
               },                   
               
               },
               
               } 
        }, 
    "Asa":{
        "acronym": "ASA",
        "name": "Asa Research Station",
        "is_active": True,
        "locations":
           {
                1:{
                   "name": "Nybygget",
                   "acronym": "NYB",
                   "description": "",
                   "ecosystems":["CON"],
                   "is_active": True,
               },
                2:{
                   "name": "Nybygget Fixed Sensor 01",
                   "acronym": "NYF-01",
                   "description": "SWE-ASA-NYB-FOR-F01-01",
                   "ecosystems":["CON"],
                   "is_active": True,
               },                
                3:{
                   "name": "Nybygget Fixed Sensor 02",
                   "acronym": "NYF-02",
                   "description": "SWE-ASA-NYB-FOR-F01-02",
                   "ecosystems":["CON"],
                   "is_active": True,
               },
                4:{
                   "name": "Nybygget Phenocam 01",
                   "acronym": "NYP-01",
                   "description": "SP01",
                   "ecosystems":["CON"],
                   "is_active": True,
               },                
                5:{
                   "name": "ASA UAV area before 2020",
                   "acronym": "ASU asa2020",
                   "description": "ASU(past)",
                   "ecosystems":["CON"],
                   "is_active": True,
               },
                6:{
                   "name": "ASA UAV area before 2021",
                   "acronym": "ASU asa2021",
                   "description": "ASU(Prsent)",
                   "ecosystems":["CON"],
                   "is_active": True,
               },
                7:{
                   "name": "ASA UAV area 2024",
                   "acronym": "ASU01",
                   "description": "",
                   "ecosystems":["CON"],
                   "is_active": True,
               },                         
            
           }
           },
    "Bolmen":{
        "acronym": "BOL",
        "name": "Bolmen Research Station",
        "is_active": True,
        "locations":
           {
                1:{
                   "name": "Bolmen Research Station",
                   "acronym": "BOL",
                   "description": "",
                   "ecosystems":[],
                   "is_active": True,
               },

           }
           },
    "Erken":{
        "acronym": "ERK",
        "name": "Erken Laboratory",
        "is_active": True,
        "locations":
           {
                1:{
                   "name": "Erken",
                   "acronym": "Erken",
                   "description": "",
                   "ecosystems":[],
                   "is_active": True,
               },

           }
           },
    "Grimsö":{
        "acronym": "GRI",
        "name": "Grimsö Wildlife Research Station",
        "is_active": True,
        "locations":
           {
                1:{
                   "name": "Grimsö Wildlife Research Station",
                   "acronym": "GRI",
                   "description": "Spectral Camera",
                   "ecosystems":[],
                   "is_active": True,
               },

           }
           },
    "Lönnstorp":{
        "acronym": "LON",
        "name": "Lönnstorp Reasearch Station",
        "is_active": True,
        "locations":
           {
                1:{
                   "name": "Mast 10m",
                   "acronym": "SFA-M10F1",
                   "description": "Lönnstorp Experimental Fields, SWE-LON-SFA-AGR-F01-01, Sensor 01, M10F1",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                2:{
                   "name": "Mast 10m",
                   "acronym": "SFA-M10F2",
                   "description": "Lönnstorp Experimental Fields, SWE-LON-SFA-AGR-F01-02, Sensor 02, M10F2",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                3:{
                   "name": "Mast 10m",
                   "acronym": "SAFE-M10",
                   "description": "Lönnstorp Experimental Fields, SAFE M10M",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                4:{
                   "name": "Mast 4m",
                   "acronym": "SFA-M4M",
                   "description": "Lönnstorp Experimental Fields, SAFE, Mast 4m, Follows Winter weat in the crop rotation",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                5:{
                   "name": "Mast 4m fixed sensor",
                   "acronym": "SFA-M4F",
                   "description": "Lönnstorp Experimental Fields, SWE-LON-SFA-AGR-F02, Mast 4m fixed sensor",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },                                
                6:{
                   "name": "Mast 10m",
                   "acronym": "M10P01",
                   "description": "Lönnstorp Experimental Fields, Mast 10m Penocam 01",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                7:{
                   "name": "Mast 10m",
                   "acronym": "M10P02",
                   "description": "Lönnstorp Experimental Fields, Mast 10m Penocam 02",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                8:{
                   "name": "Mast 10m",
                   "acronym": "M10P03",
                   "description": "Lönnstorp Experimental Fields, Mast 10m Penocam 03",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                9:{
                   "name": "ROI UAV",
                   "acronym": "EKO",
                   "description": "Organic Experimental Field UAV, UAV LonEKO2020",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                10:{
                   "name": "ROI UAV",
                   "acronym": "SFA",
                   "description": "UAV SAFE A 2020",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                11:{
                   "name": "ROI UAV",
                   "acronym": "SFB",
                   "description": "UAV SAFE B 2020",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                12:{
                   "name": "ROI UAV",
                   "acronym": "SFAB",
                   "description": "UAV SAFE AB2021",
                   "ecosystems":["AGR"],
                   "is_active": True,
               },
                
           }
           },
    "Röbacksdalen":{
        "acronym": "RBD",
        "name": "Röbacksdalen Field Research Station",
        "is_active": True,
        "locations":
           {
                0:{
                   "name": "Röbacksdalen",
                   "acronym": "RBD",
                   "description": "",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                1:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M4F",
                   "description": "SWE-RBD-RBD-AGR-F02, 4m mast fixed sensor",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                2:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M4PH",
                   "description": "4m mast phenocam, P02",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                3:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M4M",
                   "description": "Field 13 mast 4m new, Mast02 4m",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },            
                4:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M10M",
                   "description": "Field 14 mast 10m, Mast01 10m",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                5:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M10F2",
                   "description": "SWE-RBD-RBD-AGR-F01-02, 10m mast fixed sensor 02",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                6:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M10F1",
                   "description": "SWE-RBD-RBD-AGR-F01-01, 10m mast fixed sensor 01",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                7:{
                   "name": "Röbäcksdalen Experimental Fields - North",
                   "acronym": "M10PH",
                   "description": "10m mast phenocam, P01",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                8:{
                   "name": "Drone area 01_until2020",
                   "acronym": "D01-2020",
                   "description": "UAV rbdAGR2020_U01",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                9:{
                   "name": "Drone area 02_until2020",
                   "acronym": "D02-2020",
                   "description": "UAV rbdAGR2020_U02",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                10:{
                   "name": "Drone area 02_from2021",
                   "acronym": "D02-2021",
                   "description": "UAV rbdAGR2021_U02",
                   "ecosystems":['AGR'],
                   "is_active": True,
                   
               },
                11:{
                   "name": "Drone area 01_from2021",
                   "acronym": "D01-2021",
                   "description": "UAV rbdAGR2021_U01",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },
                12:{
                   "name": "Drone area 03",
                   "acronym": "D03",
                   "description": "SWE_RBD_RBD_AGR_U03",
                   "ecosystems":['AGR'],
                   "is_active": True,
               },                
           }
           },
    "Skögaryd":{
        "acronym": "SKC",  # NOTE The acronym used in locations is different = SRC
        "name": "Skogaryd Research Catchment",
        "is_active": True,
        "locations":
           {
                0:{
                   "name": "Skogaryd Research Catchment",
                   "acronym": "SRC",
                   "description": "",
                   "ecosystems":['CON', 'MAR', 'MIR', 'FOR'],
                   "is_active": True,
               },
                1:{
                   "name": "Följemaden Catchment",
                   "acronym": "MAD",
                   "description": "Följemaden",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                2:{
                   "name": "Följemaden Catchment",
                   "acronym": "MCM05",
                   "description": "Phenocam Replanted, C-mast-5",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                3:{
                   "name": "Följesjön Catchment",
                   "acronym": "FCM03",
                   "description": "Phenocam Phrag NDVI, C-mast-3",
                   "ecosystems":['MAR'],
                   "is_active": True,
                4:{
                   "name": "Följesjön Catchment",
                   "acronym": "FCM04",
                   "description": "Phenocam North, C-mast-4",
                   "ecosystems":['MAR'],
                   "is_active": True,
               },
                5:{
                   "name": "Följesjön Catchment",
                   "acronym": "FM03F",
                   "description": "SWE-SRC-FOL-WET-F01, C-mast-3-Fixed sensor",
                   "ecosystems":['MAR'],
                   "is_active": True,
               },
                6:{
                   "name": "Följesjön Catchment",
                   "acronym": "FM02F",
                   "description": "SWE-SRC-MYC-MYR-F01-02, C-mast-2-Fixed sensor",
                   "ecosystems":['MAR'],
                   "is_active": True,
               },
                7:{
                   "name": "Mycklemossen Catchment",
                   "acronym": "MM3F01",
                   "description": "SWE-SRC-MYC-MYR-F01-01, S-mast-3-Fixed sensor 01",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                8:{
                   "name": "Mycklemossen Catchment",
                   "acronym": "MM3F02",
                   "description": "SWE-SRC-MYC-MYR-F01-02, S-mast-3-Fixed sensor 02",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                9:{
                   "name": "Mycklemossen Catchment",
                   "acronym": "MM3F03",
                   "description": "SWE-SRC-MYC-MYR-F01-03, S-mast-3-Fixed sensor 03",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                10:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "SRC",
                   "description": "Skogaryd Central",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                11:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CEM02",
                   "description": "Phenocam NDVI 2 West, Mast-2",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                12:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CEM03",
                   "description": "Phenocam NDVI 3 East, Mast-3",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                13:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM1F1",
                   "description": "SWE-SRC-CEN-FOR-F01-01, Mast 1-fixed sensor 01",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                14:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM1F2",
                   "description": "SWE-SRC-CEN-FOR-F01-02, Mast 1-fixed sensor 02",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                15:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM2F",
                   "description": "SWE-SRC-CEN-FOR-F02, Mast-2 fixed sensor",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                16:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM3F",
                   "description": "SWE-SRC-CEN-FOR-F03, Mast-3 fixed sensor",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                17:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM1P",
                   "description": "P01, Mast 1 phenocam",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                18:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM2P",
                   "description": "P02, Mast 2 phenocam",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                19:{
                   "name": "Skogaryd Central Catchment",
                   "acronym": "CM3P",
                   "description": "P03, Mast 3 phenocam",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                20:{
                   "name": "Skogaryd Stordalen Catchment",
                   "acronym": "STD",
                   "description": "Stordalen",
                   "ecosystems":['FOR'],
                   "is_active": True,
               },
                21:{
                   "name": "Skogaryd Stordalen Catchment",
                   "acronym": "STMP",
                   "description": "P01, Skogaryd Stordalen mast phenocam",
                   "ecosystems":['FOR'],
                   "is_active": True,
               },
                21:{
                   "name": "UAV Följesjön",
                   "acronym": "FOLU",
                   "description": "UAV SkogarydFOL2020-21",
                   "ecosystems":['MAR'],
                   "is_active": True,
               },
                22:{
                   "name": "UAV Mycklemossen from2021",
                   "acronym": "MYCU",
                   "description": "UAV mycklemossen2021, MYCU(present)",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                23:{
                   "name": "UAV Mycklemossen before2020",
                   "acronym": "MYCUOLD",
                   "description": "UAV mycklemossen2020, MYCU(past)",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                24:{
                   "name": "UAV Skogaryd Stordalen",
                   "acronym": "STDU",
                   "description": "UAV StordalenClearcut2020-21, STDU",
                   "ecosystems":['FOR'],
                   "is_active": True,
               },
                24:{
                   "name": "UAV Följemaden from2021",
                   "acronym": "MADU",
                   "description": "UAV src-maden2021, MADU(present)",
                   "ecosystems":['PEA'],
                   "is_active": True,
               },
                25:{
                   "name": "UAV Följemaden before2020",
                   "acronym": "OMADU",
                   "description": "UAV src-maden2020, MADU(past)",
                   "ecosystems":['PEA'],
                   "is_active": True,
               },
                26:{
                   "name": "UAV Skogaryd Central",
                   "acronym": "CENU",
                   "description": "UAV SkogarydCentral2021",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                
           }
           },
    "Svartberget":{
        "acronym": "SVB",
        "name": "Svartberget Research Station",
        "is_active": True,
        "locations":
           {
                0:{
                   "name": "Svartberget Research Station",
                   "acronym": "SVB",
                   "description": "",
                   "ecosystems":['MIR, PEA', 'CON'],
                   "is_active": True,
               },
                1:{
                   "name": "Degerö Catchment",
                   "acronym": "DEG",
                   "description": "Degerö spectral mast",
                   "ecosystems":['MIR', 'PEA'],
                   "is_active": True,
               },
                2:{
                   "name": "Svartberget Experimental Forest",
                   "acronym": "SVB",
                   "description": "Svartberget, Spectral Mast",
                   "ecosystems":['CON'],
                   "is_active": True,
               },
                3:{
                   "name": "Svartberget Research Station",
                   "acronym": "DEGU",
                   "description": "UAV degero2020-21",
                   "ecosystems":['MIR'],
                   "is_active": True,
               },
                4:{
                   "name": "Svartberget Research Station",
                   "acronym": "SVBU",
                   "description": "UAV svartbergetFOR2020",
                   "ecosystems":['CON'],
                   "is_active": True,
               },                                                                

           }
           },
    "Tarfala":{
        "acronym": "TRS",
        "name": "Tarfala Research Station",
        "is_active": False,
        "locations":
           {
                0:{
                   "name": "Tarfala Research Station",
                   "acronym": "TRS",
                   "description": "",
                   "ecosystems":[],
                   "is_active": True,
               },
                1:{
                   "name": "Laevasvagge",
                   "acronym": "SPC",
                   "description": "Laevasvagge spectral mast",
                   "ecosystems":[],
                   "is_active": True,
               },
                2:{
                   "name": "Laevasvagge",
                   "acronym": "M4P1",
                   "description": "Mast 4m Phenocam 01",
                   "ecosystems":[],
                   "is_active": True,
               },
                3:{
                   "name": "UAV Laevasvagge until2020",
                   "acronym": "OLAEU",
                   "description": "LAEU(past)",
                   "ecosystems":[],
                   "is_active": True,
               },
                4:{
                   "name": "UAV Laevasvagge from2021",
                   "acronym": "LAEU",
                   "description": "LAEU(present)",
                   "ecosystems":[],
                   "is_active": True,
               },                                                


           }
           },
    }
} 




