__version__ = '0.25.2.0'
version_code_sstc_core = __version__
version_data_processing = '3.0-2025'
version_platform_iflags = '0.8-2025'  ## Added description and DwC compatibility
version_qflag = '0.3-2024'
version_schema_platform_phenocams = '0.8-2024'
version_phenocam_app = '0.2.1'  # transition towards phenocam viewer
